# Dokku CLI Python

This program is a Python reimplementation of dokku's CLI program.

We expect it to work on the following operating systems:

1. Windows 10 or later
1. macOS
1. Debian/Ubuntu, RHEL/Cent/Rocky, etc.

This program requires Python 3.10 or later. 

And you should be able to use ssh and git commands.

## Installation

We recommend pipx as the method for installing this program. This assumes that you have pipx installed.

```shell
$ pipx install dokku-py
```

## Usage

Simply run the dokku command in your shell. For the available commands, see the documentation on the dokku homepage.

```shell
$ dokku command
```

## Contributing

If you find a bug in this program or a feature you'd like to see added, please write an issue.
